" Vim indent file
" Language:     JSON5
" Maintainer:   The Vim Project <https://github.com/vim/vim>
" Last Change:  2024-03-26

if exists("b:did_indent")
  finish
endif

" Same as jsonc indenting for now
runtime! indent/jsonc.vim
