" Vim Keymap file for latin1 accents through dead characters
" Maintainer:	The Vim Project <https://github.com/vim/vim>
" Last Change:	2023 Aug 13

" All characters are given literally, conversion to another encoding (e.g.,
" UTF-8) should work.
scriptencoding latin1

" Use this short name in the status line.
let b:keymap_name = "acc"

loadkeymap
`A	À
'A	Á
´A	Á
^A	Â
~A	Ã
:A	Ä
'C	Ç
´C	Ç
`E	È
'E	É
´E	É
^E	Ê
`I	Ì
'I	Í
´I	Í
^I	Î
~N	Ñ
`O	Ò
'O	Ó
´O	Ó
^O	Ô
~O	Õ
:O	Ö
`U	Ù
'U	Ú
´U	Ú
^U	Û
:U	Ü
'Y	Ý
´Y	Ý
`a	à
'a	á
´a	á
^a	â
~a	ã
:a	ä
'c	ç
´c	ç
`e	è
'e	é
´e	é
^e	ê
`i	ì
'i	í
´i	í
^i	î
~n	ñ
`o	ò
'o	ó
´o	ó
^o	ô
~o	õ
:o	ö
`u	ù
'u	ú
´u	ú
^u	û
:u	ü
'y	ý
´y	ý
''	'
´´	´
``	`
^^	^
~~	~
::	:
